tablespace_bandwidth_limit
:   This  option  allows  you  to specify a maximum transfer rate in
    kilobytes per second, by specifying a comma separated list of
    tablespaces (pairs TBNAME:BWLIMIT). A value of zero specifies no limit
    (default).

    Scope: Global/Server/Model.
